@@ -3,7 +3,6 @@ from typing import Callable, List, Union, Dict
 import plotly.graph_objects as go
 
 from .calculations._helper import *
-
 from .calculations._functional import _functionaldepth, _samplefunctionaldepth
 from .calculations._pointcloud import _pointwisedepth, _samplepointwisedepth
 from .abstract import AbstractDepth
@@ -85,28 +84,70 @@ class _FunctionalDepthUnivariate(_FunctionalDepthSeries):
     def __init__(self, df: pd.DataFrame, depths: pd.Series):
         super().__init__(df=df, depths=depths)
 
-    def _plot(self, deep_or_outlying: pd.Series) -> None:
+    def _plot(
+        self, 
+        deep_or_outlying: pd.Series, 
+        title: str, 
+        xaxis_title: str,
+        yaxis_title: str,
+        return_plot: bool,
+    ) -> None:
         cols = self._orig_data.columns
         x = self._orig_data.index
 
         # We use deep_or_outlying.index to get the columns because 
         # deep_or_outlying is a Series indexed by the original columns
         
-        data=[go.Scatter(x=x, y=self._orig_data.loc[:, y], mode='lines', line=dict(color='Blue', width=.5)) for y in cols]
-        data.extend([go.Scatter(x=x, y=self._orig_data.loc[:, y], mode='lines', line=dict(color='Red', width=2)) for y in deep_or_outlying.index])
+        data=[go.Scatter(x=x, y=self._orig_data.loc[:, y], mode='lines', line=dict(color='#6ea8ff', width=.5)) for y in cols]
+        data.extend([go.Scatter(x=x, y=self._orig_data.loc[:, y], mode='lines', line=dict(color='Red', width=1)) for y in deep_or_outlying.index])
+
+        fig = go.Figure(
+            data=data, 
+            layout=go.Layout(
+                title=dict(text=title, y=0.9, x=0.5, xanchor='center', yanchor='top'),
+                xaxis=dict(title=xaxis_title),
+                yaxis=dict(title=yaxis_title)
+            )
+        )
 
-        fig = go.Figure(data=data)
         fig.update_layout(showlegend=False)
+        
+        if return_plot:
+            return fig
+        else:
+            fig.show()
 
-        fig.show()
-
-    def plot_deepest(self, n=1) -> None:
+    def plot_deepest(
+        self, n=1, 
+        title=None, 
+        xaxis_title = None,
+        yaxis_title = None,
+        return_plot=False
+    ) -> None:
         '''Plots all the data in blue and marks the n deepest in red'''
-        self._plot(deep_or_outlying=self.deepest(n=n))
+        return self._plot(
+            deep_or_outlying=self.deepest(n=n), 
+            title=title,
+            xaxis_title=xaxis_title,
+            yaxis_title=yaxis_title,
+            return_plot=return_plot,
+        )
 
-    def plot_outlying(self, n=1) -> None:
+    def plot_outlying(
+        self, n=1, 
+        title=None, 
+        xaxis_title = None,
+        yaxis_title = None,
+        return_plot=False
+    ) -> None:
         '''Plots all the data in blue and marks the n most outlying curves in red'''
-        self._plot(deep_or_outlying=self.outlying(n=n))
+        return self._plot(
+            deep_or_outlying=self.outlying(n=n), 
+            title=title, 
+            xaxis_title=xaxis_title,
+            yaxis_title=yaxis_title,
+            return_plot=return_plot,
+        )
 
     # Have to redefine these because in the univariate case our samples are column based
     def drop_outlying_data(self, n=1) -> pd.DataFrame:
