@@ -110,7 +110,7 @@ def _functionalhomogeneity(
             relax=relax,
             deep_check=deep_check,
             quiet=quiet,
-        ).ordered().loc['g_deepest']
+        )
         
         F = F.drop('g_deepest', axis=1)
 
@@ -214,3 +214,98 @@ def _handle_errors(F: List[pd.DataFrame], G: List[pd.DataFrame], method='p1'):
     else:
         pass
 
+
+def P1_homogeneity(
+    F: pd.DataFrame, 
+    G: pd.DataFrame,
+    K=None, 
+    J=2, 
+    containment='r2', 
+    relax=False,
+    quiet=False
+) -> float:
+    '''
+    Calculates the P1 homogeneity coefficient between the samples F and G.    
+    Closer to 1 means the two experiments were likely generated by the same process.
+    
+    Parameters:
+    ----------
+    F: pd.DataFrame: An m x n DataFrame where each n functions are sampled at m points
+    G: pd.DataFrame: An m x n DataFrame where each n functions are sampled at m points
+
+    Returns:
+    ----------
+    float: P1 homogeneity coefficient
+    '''
+    
+    # Find the deepest function in G
+    G_depth = FunctionalDepth(
+        data=[G],
+        K=K,
+        J=J,
+        containment=containment,
+        relax=relax, 
+        quiet=quiet,
+    )
+    
+    G_deepest = G_depth.get_deep_data()
+
+    F.loc[:, 'G_deepest'] = G_deepest
+    
+    G_deep_in_F = FunctionalDepth(
+        [F],
+        to_compute=['G_deepest'],
+        K=K,
+        J=J,
+        containment=containment,
+        relax=relax,
+        quiet=quiet
+        
+    )
+    
+    return G_deep_in_F.iloc[0]
+
+def P2_homogeneity(
+    F: pd.DataFrame, 
+    G: pd.DataFrame,
+    K=None, 
+    J=2, 
+    containment='r2', 
+    relax=False,
+    quiet=False
+) -> float:
+    '''
+    Calculates the P2 homogeneity coefficient between the samples F and G.
+    Closer to 0 means the two experiments likely are generated by the same process.
+    
+    Parameters:
+    ----------
+    F: pd.DataFrame: An m x n DataFrame where each n functions are sampled at m points
+    G: pd.DataFrame: An m x n DataFrame where each n functions are sampled at m points
+
+    
+    Returns:
+    ----------
+    float: P2 homogeneity coefficient
+    '''
+
+    P1_F_G = P1_homogeneity(
+        F=F,
+        G=G,
+        K=K,
+        J=J,
+        containment=containment,
+        relax=relax,
+        quiet=quiet
+    )
+
+    P1_F_F = FunctionalDepth(
+        data=[F],
+        K=K,
+        J=J,
+        containment=containment,
+        relax=relax,
+        quiet=quiet
+    ).deepest().iloc[0]
+    
+    return np.abs(P1_F_G - P1_F_F)
\ No newline at end of file
